==> codebuild-1.60.0-sources.jar: software/amazon/awscdk/services/codebuild/FileSystemLocation.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * FileSystemLocation provider definition for a CodeBuild Project.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:30.406Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.FileSystemLocation")
public class FileSystemLocation extends software.amazon.jsii.JsiiObject {

    protected FileSystemLocation(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected FileSystemLocation(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    public FileSystemLocation() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * EFS file system provider.
     * <p>
     * @param props the EFS File System location property. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.IFileSystemLocation efs(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.EfsFileSystemLocationProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.FileSystemLocation.class, "efs", software.amazon.awscdk.services.codebuild.IFileSystemLocation.class, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }
}

==> codebuild-1.93.0-sources.jar: software/amazon/awscdk/services/codebuild/FileSystemLocation.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * FileSystemLocation provider definition for a CodeBuild Project.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:47.775Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.FileSystemLocation")
public class FileSystemLocation extends software.amazon.jsii.JsiiObject {

    protected FileSystemLocation(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected FileSystemLocation(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public FileSystemLocation() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * EFS file system provider.
     * <p>
     * @param props the EFS File System location property. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.IFileSystemLocation efs(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.EfsFileSystemLocationProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.FileSystemLocation.class, "efs", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codebuild.IFileSystemLocation.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }
}
